==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/types/Db4oCollection.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.types
{
	/// <summary>base interface for db4o collections</summary>
	public interface Db4oCollection : com.db4o.types.Db4oType
	{
		/// <summary>configures the activation depth for objects returned from this collection.
		/// 	</summary>
		/// <remarks>
		/// configures the activation depth for objects returned from this collection.
		/// <br /><br />Specify a value less than zero to use the default activation depth
		/// configured for the ObjectContainer or for individual objects.
		/// </remarks>
		/// <param name="depth">the desired depth</param>
		void activationDepth(int depth);

		/// <summary>
		/// configures objects are to be deleted from the database file if they are
		/// removed from this collection.
		/// </summary>
		/// <remarks>
		/// configures objects are to be deleted from the database file if they are
		/// removed from this collection.
		/// <br /><br />Default value: <code>false</code>
		/// </remarks>
		/// <param name="flag">the desired setting</param>
		void deleteRemoved(bool flag);
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/types/Db4oCollection.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.types
{
	/// <summary>base interface for db4o collections</summary>
	public interface Db4oCollection : com.db4o.types.Db4oType
	{
		/// <summary>configures the activation depth for objects returned from this collection.
		/// 	</summary>
		/// <remarks>
		/// configures the activation depth for objects returned from this collection.
		/// <br /><br />Specify a value less than zero to use the default activation depth
		/// configured for the ObjectContainer or for individual objects.
		/// </remarks>
		/// <param name="depth">the desired depth</param>
		void ActivationDepth(int depth);

		/// <summary>
		/// configures objects are to be deleted from the database file if they are
		/// removed from this collection.
		/// </summary>
		/// <remarks>
		/// configures objects are to be deleted from the database file if they are
		/// removed from this collection.
		/// <br /><br />Default value: <code>false</code>
		/// </remarks>
		/// <param name="flag">the desired setting</param>
		void DeleteRemoved(bool flag);
	}
}
